@@ -50,7 +50,7 @@
 #'
 #' \item\code{3035}: ETRS-LAEA, projected coordinate system. The
 #' columns in \code{x} must be defined as Easting and Northing. The defined
-#' datum for this set of coordinates is WGS84 (https://epsg.io/3035)
+#' datum for this set of coordinates is ETRS89 (https://epsg.io/3035)
 #'
 #' \item\code{4326}: WGS84, geodetic coordinate system. The columns in \code{x}
 #' must be defined as Longitude and Latitude (\code{sgo} also accepts a
@@ -156,12 +156,12 @@ sgo_points.list <- function (x, coords=NULL, epsg=NULL) {
     }
   }
 
-  names <- names(x)
-  if (is.null(names) || any(names == "")) {
+  x.names <- names(x)
+  if (is.null(x.names) || any(x.names == "")) {
     stop("All elements in 'x' must be named")
   }
 
-  if (!is.null(coords) && !all(coords %in% names)) {
+  if (!is.null(coords) && !all(coords %in% x.names)) {
     stop("'x' must include all the coordinates defined in 'coords'")
   }
 
@@ -204,7 +204,7 @@ sgo_points.list <- function (x, coords=NULL, epsg=NULL) {
                          z = x[[coords[3]]])
   }
 
-  other.columns <- x[!(names %in% coords)]
+  other.columns <- x[!(x.names %in% coords)]
 
   if (length(other.columns)==0) {
     other.columns <- NULL
@@ -295,8 +295,19 @@ sgo_points.matrix <- function (x, coords=NULL, epsg=NULL) {
 #' Extract the coordinates of an \code{sgo_points} object expressed as a matrix.
 #'
 #' @name sgo_coordinates
-#' @usage sgo_coordinates(x)
+#' @usage sgo_coordinates(x, names.xyz = NULL, as.latlon = FALSE,
+#' ll.format=NULL)
 #' @param x An instance of \code{sgo_points}.
+#' @param names.xyz Character vector. New names for the columns x, y and
+#' possibly z of the object \code{x}.
+#' @param as.latlon Logical variable. When \code{x} is defined in a geodetic
+#' coordinate system as lon/lat and this parameter is set to \code{TRUE} then
+#' it returns the coordinates ordered as lat/lon.
+#' @param ll.format Character variable. Applies a format to the returned
+#' coordinates when \code{x} is defined in a geodetic coordinate system. As of
+#' now it only accepts \code{DMS}, which will return strings of
+#' coordinates formatted as degrees, minutes and seconds (certain accuracy will
+#' be lost because seconds are rounded to the second decimal).
 #' @return
 #' A matrix with 2 or 3 named columns.
 #' @examples
@@ -304,10 +315,12 @@ sgo_points.matrix <- function (x, coords=NULL, epsg=NULL) {
 #' coords <- sgo_coordinates(p)
 #'
 #' @export
-sgo_coordinates <- function (x) UseMethod("sgo_coordinates")
+sgo_coordinates <- function (x, names.xyz=NULL, as.latlon=FALSE, ll.format=NULL)
+  UseMethod("sgo_coordinates")
 
 #' @export
-sgo_coordinates.sgo_points <- function(x) {
+sgo_coordinates.sgo_points <- function(x, names.xyz=NULL, as.latlon=FALSE,
+                                       ll.format=NULL) {
 
   if(x$dimension == "XY") {
     coords <- .sgo_points.2d.coords
@@ -316,8 +329,44 @@ sgo_coordinates.sgo_points <- function(x) {
     coords <- .sgo_points.3d.coords
     cols <- 3
   }
-  matrix(unlist(x[coords], use.names = FALSE), ncol = cols, byrow = FALSE,
-         dimnames = list(NULL, coords))
+
+  is.ll <- .epsgs[.epsgs$epsg == x$epsg, "format"] == "ll"
+
+  # set the new names for the coordinates columns
+  if (!is.null(names.xyz)) {
+    if (length(names.xyz) > length(coords)) {
+      dim.names <- replace(coords, values = names.xyz[1:length(coords)])
+    } else {
+      dim.names <- replace(coords, 1:length(names.xyz), names.xyz)
+    }
+  } else {
+    dim.names <- coords
+  }
+
+  if (is.ll) {
+    if (as.latlon) {
+      # change order of coords and dim.names
+      coords <- c(coords[2], setdiff(coords, coords[2]))
+      dim.names <- c(dim.names[2], setdiff(dim.names, dim.names[2]))
+    }
+    vec.coords <- unlist(x[coords], use.names = FALSE)
+    len.vec <- length(vec.coords)
+    if (!is.null(ll.format)) {
+      if(ll.format == "DMS") {
+        if (cols == 3) {
+          vec.coords[1:(len.vec/3*2)] <- .dd.to.dms(vec.coords[1:(len.vec/3*2)],
+                                                    as.latlon, 2)
+        } else {
+          vec.coords <- .dd.to.dms(vec.coords, as.latlon, 2)
+        }
+      }
+    }
+  } else {
+    vec.coords <- unlist(x[coords], use.names = FALSE)
+  }
+
+  matrix(vec.coords, ncol = cols, byrow = FALSE,
+         dimnames = list(NULL, dim.names))
 
 }
 
@@ -372,7 +421,8 @@ as.data.frame.sgo_points <- function(x,
                                      row.names = NULL, optional = FALSE, ...) {
 
   col.names <- setdiff(names(x), .sgo_points.attr)
-  as.data.frame.list(x[col.names], col.names = col.names)
+  as.data.frame.list(x[col.names], row.names = row.names, optional = optional,
+                     col.names = col.names)
 
 }
 
@@ -384,3 +434,46 @@ as.list.sgo_points <- function(x, ...) {
   x[setdiff(names(x), .sgo_points.attr)]
 
 }
+
+
+# dd.coords is a vector of coordinates
+# as.latlon is a logical value.
+# num.decimals is a hscalar value.
+.dd.to.dms <- function(coords, as.latlon, num.decimals = 0) {
+
+  # a typical tolerance: tol = sqrt(.Machine$double.eps)
+  tol <- 60
+
+  len <- length(coords)
+  signs <- coords < 0
+  if (as.latlon) {
+    letters <- c(ifelse(signs[1:(len/2)], "S", "N"),
+                 ifelse(signs[(len/2+1):len], "W", "E"))
+  } else {
+    letters <- c(ifelse(signs[1:(len/2)], "W", "E"),
+                 ifelse(signs[(len/2+1):len], "S", "N"))
+  }
+
+  coords <- abs(coords)
+  d <- trunc(coords)
+  ms <- (coords - d) * 60
+  m <- trunc(ms)
+  s <- round((ms - m) * 60, num.decimals)
+
+  above.tol <- s != tol
+  s <- ifelse(above.tol, s, 0)
+  m <- ifelse(above.tol, m, m + 1)
+  keep.min <- as.integer(m) < 60L
+  m <- ifelse(keep.min, m, 0)
+  d <- ifelse(keep.min, d, d + 1)
+
+  sprintf("%d%s %d%s %.*f%s %s", d, "\U00B0", m, "\U2032",
+          num.decimals, s, "\U2033", letters)
+  #sprintf("%d%s %d%s %.*f%s %s", d, "\U00B0", m, "\U2032",
+  #        num.decimals, trunc(s * 10^num.decimals) / 10^num.decimals, "\U2033",
+  #        letters)
+  # Not using num.decimals:
+  #sprintf("%d%s %d%s %.*f%s %s", d, "\U00B0", m, "\U2032",
+  #        num.decimals, trunc(s), "\U2033", letters)
+
+}
